bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDDistribution
=================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: GaussianGammaARDDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaARDDistribution.__init__
      ~GaussianGammaARDDistribution.compute_cgf_from_parents
      ~GaussianGammaARDDistribution.compute_fixed_moments_and_f
      ~GaussianGammaARDDistribution.compute_gradient
      ~GaussianGammaARDDistribution.compute_logpdf
      ~GaussianGammaARDDistribution.compute_mask_to_parent
      ~GaussianGammaARDDistribution.compute_message_to_parent
      ~GaussianGammaARDDistribution.compute_moments_and_cgf
      ~GaussianGammaARDDistribution.compute_phi_from_parents
      ~GaussianGammaARDDistribution.plates_from_parent
      ~GaussianGammaARDDistribution.plates_to_parent
      ~GaussianGammaARDDistribution.random
   
   

   
   
   